@@ -23,7 +23,7 @@
 # WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 # FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 # OTHER DEALINGS IN THE SOFTWARE.
-version = '0.5'
+version = '0.5.1'
 
 import re
 import socket
@@ -75,7 +75,7 @@ def utf8(s):
     return str(s)
 
 
-class HTTPrettyRequest(BaseHTTPRequestHandler):
+class HTTPrettyRequest(BaseHTTPRequestHandler, object):
     def __init__(self, headers, body=''):
         self.body = utf8(body)
         self.raw_headers = utf8(headers)
